@@ -47,8 +47,13 @@ class ConfigService:
             Log.error('Error while communicating with the Moodle System! (%s)' % (error))
             sys.exit(1)
 
-        self._select_courses_to_download(courses)
-        self._set_options_of_courses(courses)
+        course_ids = self._select_courses_to_download(courses)
+
+        sections = {}
+        for course_id in course_ids:
+            sections[course_id] = first_contact_handler.fetch_sections(course_id)
+
+        self._set_options_of_courses(courses, sections)
         self._select_should_download_submissions()
         self._select_should_download_descriptions()
         self._select_should_download_links_in_descriptions()
@@ -147,7 +152,7 @@ class ConfigService:
                     'create_directory_structure': True,
                 }
 
-            options_of_courses.update({str(course.id): current_course_settings})
+                options_of_courses.update({str(course.id): current_course_settings})
 
             if course.id not in download_public_course_ids:
                 download_public_course_ids.append(course.id)
@@ -225,8 +230,37 @@ class ConfigService:
         self.config_helper.set_property('download_course_ids', download_course_ids)
 
         self.config_helper.remove_property('dont_download_course_ids')
+        return download_course_ids
 
-    def _set_options_of_courses(self, courses: [Course]):
+    def _select_sections_to_download(self, sections: [{}], excluded: [int]) -> [int]:
+        """
+        Asks the user for the sections that should be downloaded.
+        @param sections: All available sections
+        @param excluded sections currently excluded
+        """
+
+        choices = []
+        defaults = []
+        for i, section in enumerate(sections):
+            section_id = section.get("id")
+            choices.append(('%5i\t%s' % (section_id, section.get("name"))))
+
+            if ResultsHandler.should_download_section(section_id, excluded):
+                defaults.append(i)
+
+        Log.special('Which of the sections should be downloaded?')
+        Log.info('[You can select with the space bar and confirm your selection with the enter key]')
+        print('')
+        selected_sections = cutie.select_multiple(options=choices, ticked_indices=defaults)
+
+        dont_download_section_ids = []
+        for i, section in enumerate(sections):
+            if i not in selected_sections:
+                dont_download_section_ids.append(section.get("id"))
+
+        return dont_download_section_ids
+
+    def _set_options_of_courses(self, courses: [Course], sections: []):
         """
         Let the user set special options for every single course
         """
@@ -239,7 +273,8 @@ class ConfigService:
             + 'You can set these options:\n'
             + ' - A different name for the course\n'
             + ' - If a directory structure should be created for the course'
-            + ' [create_directory_structure (cfs)].'
+            + ' [create_directory_structure (cfs)]\n'
+            + ' - Which of the sections should be downloaded (default all).'
         )
         print('')
 
@@ -263,6 +298,7 @@ class ConfigService:
                             'original_name': course.fullname,
                             'overwrite_name_with': None,
                             'create_directory_structure': True,
+                            'excluded_sections': [],
                         }
 
                     # create list of options
@@ -292,9 +328,10 @@ class ConfigService:
             if selected_course == 0:
                 break
             else:
-                self._change_settings_of(choices_courses[selected_course - 1], options_of_courses)
+                sel = choices_courses[selected_course - 1]
+                self._change_settings_of(sel, options_of_courses, sections[sel.id])
 
-    def _change_settings_of(self, course: Course, options_of_courses: {}):
+    def _change_settings_of(self, course: Course, options_of_courses: {}, sections: [{}]):
         """
         Ask for a new Name for the course.
         Then asks if a file structure should be created.
@@ -308,6 +345,7 @@ class ConfigService:
                 'original_name': course.fullname,
                 'overwrite_name_with': None,
                 'create_directory_structure': True,
+                'excluded_sections': [],
             }
 
         changed = False
@@ -337,6 +375,14 @@ class ConfigService:
             changed = True
             current_course_settings.update({'create_directory_structure': create_directory_structure})
 
+        excluded_sections = current_course_settings.get('excluded_sections', [])
+
+        dont_download_section_ids = self._select_sections_to_download(sections, excluded_sections)
+
+        if dont_download_section_ids is not current_course_settings.get('excluded_sections', []):
+            changed = True
+            current_course_settings.update({'excluded_sections': dont_download_section_ids})
+
         if changed:
             options_of_courses.update({str(course.id): current_course_settings})
             self.config_helper.set_property('options_of_courses', options_of_courses)
